bayespy.nodes.SwitchingGaussianMarkovChain.set_parameters
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.set_parameters